@@ -29,8 +29,8 @@ use PostScript::File 2.20 qw(str); # need use_functions
 #=====================================================================
 # Package Global Variables:
 
-our $VERSION = '1.01';
-# This file is part of PostScript-Calendar 1.01 (February 12, 2012)
+our $VERSION = '1.02';
+# This file is part of PostScript-Calendar 1.02 (June 13, 2015)
 
 our @phaseName = qw(NewMoon FirstQuarter FullMoon LastQuarter);
 
@@ -856,8 +856,8 @@ PostScript::Calendar - Generate a monthly calendar in PostScript
 
 =head1 VERSION
 
-This document describes version 1.01 of
-PostScript::Calendar, released February 12, 2012.
+This document describes version 1.02 of
+PostScript::Calendar, released June 13, 2015.
 
 =head1 SYNOPSIS
 
@@ -1290,11 +1290,11 @@ or through the web interface at
 L<< http://rt.cpan.org/Public/Bug/Report.html?Queue=PostScript-Calendar >>.
 
 You can follow or contribute to PostScript-Calendar's development at
-L<< http://github.com/madsen/postscript-calendar >>.
+L<< https://github.com/madsen/postscript-calendar >>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Christopher J. Madsen.
+This software is copyright (c) 2015 by Christopher J. Madsen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
